@@ -1,5 +1,7 @@
-use serde::{Deserialize, Deserializer, Serialize};
+use serde::de::{Deserialize, Deserializer};
+use serde_derive::Serialize;
 use std::borrow::Cow;
+use std::env;
 use std::ffi::OsString;
 use std::io;
 use std::path::{Path, PathBuf};
@@ -17,6 +19,10 @@ impl Directory {
         Directory { path }
     }
 
+    pub fn current() -> io::Result<Self> {
+        env::current_dir().map(Directory::new)
+    }
+
     pub fn to_string_lossy(&self) -> Cow<str> {
         self.path.to_string_lossy()
     }
@@ -25,6 +31,10 @@ impl Directory {
         self.path.join(tail)
     }
 
+    pub fn parent(&self) -> Option<Self> {
+        self.path.parent().map(Directory::new)
+    }
+
     pub fn canonicalize(&self) -> io::Result<Self> {
         self.path.canonicalize().map(Directory::new)
     }
