@@ -208,7 +208,7 @@
 //! makes error messages that we care about substantially worse, it is also
 //! important to catch and report as a compiler issue.
 
-#![doc(html_root_url = "https://docs.rs/trybuild/1.0.81")]
+#![doc(html_root_url = "https://docs.rs/trybuild/1.0.88")]
 #![allow(
     clippy::collapsible_if,
     clippy::default_trait_access,
@@ -227,8 +227,10 @@
     clippy::range_plus_one,
     clippy::similar_names,
     clippy::single_match_else,
+    clippy::test_attr_in_doctest,
     clippy::too_many_lines,
     clippy::trivially_copy_pass_by_ref,
+    clippy::uninhabited_references,
     clippy::unused_self,
     clippy::while_let_on_iterator,
 )]
