@@ -1,11 +1,14 @@
 use crate::dependencies::{Dependency, Patch, RegistryPatch, TargetDependencies};
-use serde::{Deserialize, Serialize};
+use serde::ser::{SerializeMap, Serializer};
+use serde_derive::{Deserialize, Serialize};
 use std::collections::BTreeMap as Map;
 use std::ffi::OsStr;
 use std::path::PathBuf;
 
 #[derive(Serialize, Debug)]
 pub struct Manifest {
+    #[serde(rename = "cargo-features", skip_serializing_if = "Vec::is_empty")]
+    pub cargo_features: Vec<String>,
     pub package: Package,
     #[serde(skip_serializing_if = "Map::is_empty")]
     pub features: Map<String, Vec<String>>,
@@ -16,7 +19,10 @@ pub struct Manifest {
     pub bins: Vec<Bin>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub workspace: Option<Workspace>,
-    #[serde(skip_serializing_if = "Map::is_empty")]
+    #[serde(
+        serialize_with = "serialize_patch",
+        skip_serializing_if = "empty_patch"
+    )]
     pub patch: Map<String, RegistryPatch>,
     #[serde(skip_serializing_if = "Map::is_empty")]
     pub replace: Map<String, Patch>,
@@ -27,6 +33,8 @@ pub struct Package {
     pub name: String,
     pub version: String,
     pub edition: Edition,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub resolver: Option<String>,
     pub publish: bool,
 }
 
@@ -38,6 +46,8 @@ pub enum Edition {
     E2018,
     #[serde(rename = "2021")]
     E2021,
+    #[serde(rename = "2024")]
+    E2024,
 }
 
 #[derive(Serialize, Debug)]
@@ -60,7 +70,10 @@ pub struct Build {
 }
 
 #[derive(Serialize, Debug)]
-pub struct Workspace {}
+pub struct Workspace {
+    #[serde(skip_serializing_if = "Map::is_empty")]
+    pub dependencies: Map<String, Dependency>,
+}
 
 impl Default for Edition {
     fn default() -> Self {
@@ -73,3 +86,22 @@ impl AsRef<OsStr> for Name {
         self.0.as_ref()
     }
 }
+
+fn serialize_patch<S>(patch: &Map<String, RegistryPatch>, serializer: S) -> Result<S::Ok, S::Error>
+where
+    S: Serializer,
+{
+    let mut map = serializer.serialize_map(None)?;
+    for (registry, patch) in patch {
+        if !patch.crates.is_empty() {
+            map.serialize_entry(registry, patch)?;
+        }
+    }
+    map.end()
+}
+
+fn empty_patch(patch: &Map<String, RegistryPatch>) -> bool {
+    patch
+        .values()
+        .all(|registry_patch| registry_patch.crates.is_empty())
+}
