@@ -57,6 +57,7 @@ normalizations! {
     Unindent,
     AndOthers,
     StripLongTypeNameFiles,
+    UnindentAfterHelp,
     // New normalization steps are to be inserted here at the end so that any
     // snapshots saved before your normalization change remain passing.
 }
@@ -139,9 +140,7 @@ fn apply(original: &str, normalization: Normalization, context: Context) -> Stri
         }
     }
 
-    if normalization >= Unindent {
-        normalized = unindent(normalized);
-    }
+    normalized = unindent(normalized, normalization);
 
     trim(normalized)
 }
@@ -174,13 +173,13 @@ impl<'a> Filter<'a> {
 
         if prefix == Some("--> ") && self.normalization < ArrowOtherCrate {
             if let Some(cut_end) = line.rfind(&['/', '\\'][..]) {
-                let cut_start = line.find('>').unwrap() + 2;
+                let cut_start = indent + 4;
                 line.replace_range(cut_start..cut_end + 1, "$DIR/");
                 return Some(line);
             }
         }
 
-        if let Some(prefix) = prefix {
+        if prefix.is_some() {
             line = line.replace('\\', "/");
             let line_lower = line.to_ascii_lowercase();
             let target_dir_pat = self
@@ -210,10 +209,7 @@ impl<'a> Filter<'a> {
                         }
                     } else if component.len() > 17
                         && component.rfind('-') == Some(component.len() - 17)
-                        && component[component.len() - 16..].bytes().all(|b| match b {
-                            b'0'..=b'9' | b'a'..=b'f' => true,
-                            _ => false,
-                        })
+                        && is_ascii_lowercase_hex(&component[component.len() - 16..])
                     {
                         out_dir_crate_name = Some(&component[..component.len() - 17]);
                     } else {
@@ -275,22 +271,42 @@ impl<'a> Filter<'a> {
             }
             if self.normalization >= RustLib && !other_crate {
                 if let Some(pos) = line.find("/rustlib/src/rust/src/") {
-                    // ::: $RUST/src/libstd/net/ip.rs:83:1
-                    line.replace_range(line.find(prefix).unwrap() + 4..pos + 17, "$RUST");
+                    // --> /home/.rustup/toolchains/nightly/lib/rustlib/src/rust/src/libstd/net/ip.rs:83:1
+                    // --> $RUST/src/libstd/net/ip.rs:83:1
+                    line.replace_range(indent + 4..pos + 17, "$RUST");
                     other_crate = true;
                 } else if let Some(pos) = line.find("/rustlib/src/rust/library/") {
-                    // ::: $RUST/std/src/net/ip.rs:83:1
-                    line.replace_range(line.find(prefix).unwrap() + 4..pos + 25, "$RUST");
+                    // --> /home/.rustup/toolchains/nightly/lib/rustlib/src/rust/library/std/src/net/ip.rs:83:1
+                    // --> $RUST/std/src/net/ip.rs:83:1
+                    line.replace_range(indent + 4..pos + 25, "$RUST");
+                    other_crate = true;
+                } else if line[indent + 4..].starts_with("/rustc/")
+                    && line
+                        .get(indent + 11..indent + 51)
+                        .map_or(false, is_ascii_lowercase_hex)
+                    && line[indent + 51..].starts_with("/library/")
+                {
+                    // --> /rustc/c5c7d2b37780dac1092e75f12ab97dd56c30861e/library/std/src/net/ip.rs:83:1
+                    // --> $RUST/std/src/net/ip.rs:83:1
+                    line.replace_range(indent + 4..indent + 59, "$RUST");
                     other_crate = true;
                 }
             }
             if self.normalization >= CargoRegistry && !other_crate {
-                if let Some(pos) = line.find("/registry/src/github.com-") {
-                    let start_cargo = line.find(prefix).unwrap() + 4;
-                    let end_cargo = pos + 41;
-                    if line.is_char_boundary(end_cargo) {
-                        // ::: $CARGO/github.com-1ecc6299db9ec823/serde_json-1.0.64/src/de.rs:2584:8
-                        line.replace_range(start_cargo..end_cargo, "$CARGO");
+                if let Some(pos) = line
+                    .find("/registry/src/github.com-")
+                    .or_else(|| line.find("/registry/src/index.crates.io-"))
+                {
+                    let hash_start = pos + line[pos..].find('-').unwrap() + 1;
+                    let hash_end = hash_start + 16;
+                    if line
+                        .get(hash_start..hash_end)
+                        .map_or(false, is_ascii_lowercase_hex)
+                        && line[hash_end..].starts_with('/')
+                    {
+                        // --> /home/.cargo/registry/src/github.com-1ecc6299db9ec823/serde_json-1.0.64/src/de.rs:2584:8
+                        // --> $CARGO/serde_json-1.0.64/src/de.rs:2584:8
+                        line.replace_range(indent + 4..hash_end, "$CARGO");
                         other_crate = true;
                     }
                 }
@@ -396,6 +412,10 @@ impl<'a> Filter<'a> {
     }
 }
 
+fn is_ascii_lowercase_hex(s: &str) -> bool {
+    s.bytes().all(|b| matches!(b, b'0'..=b'9' | b'a'..=b'f'))
+}
+
 // "10 | T: Send,"  ->  "   | T: Send,"
 fn hide_leading_numbers(line: &mut String) {
     let n = line.bytes().take_while(u8::is_ascii_digit).count();
@@ -473,7 +493,11 @@ enum IndentedLineKind {
     Other(usize),
 }
 
-fn unindent(diag: String) -> String {
+fn unindent(diag: String, normalization: Normalization) -> String {
+    if normalization < Unindent {
+        return diag;
+    }
+
     let mut normalized = String::new();
     let mut lines = diag.lines();
 
@@ -481,7 +505,7 @@ fn unindent(diag: String) -> String {
         normalized.push_str(line);
         normalized.push('\n');
 
-        if indented_line_kind(line) != IndentedLineKind::Heading {
+        if indented_line_kind(line, normalization) != IndentedLineKind::Heading {
             continue;
         }
 
@@ -491,12 +515,12 @@ fn unindent(diag: String) -> String {
             None => continue,
         };
 
-        if let IndentedLineKind::Code(indent) = indented_line_kind(next_line) {
+        if let IndentedLineKind::Code(indent) = indented_line_kind(next_line, normalization) {
             if next_line[indent + 1..].starts_with("--> ") {
                 let mut lines_in_block = 1;
                 let mut least_indent = indent;
                 while let Some(line) = ahead.next() {
-                    match indented_line_kind(line) {
+                    match indented_line_kind(line, normalization) {
                         IndentedLineKind::Heading => break,
                         IndentedLineKind::Code(indent) => {
                             lines_in_block += 1;
@@ -515,7 +539,7 @@ fn unindent(diag: String) -> String {
                 for _ in 0..lines_in_block {
                     let line = lines.next().unwrap();
                     if let IndentedLineKind::Code(_) | IndentedLineKind::Other(_) =
-                        indented_line_kind(line)
+                        indented_line_kind(line, normalization)
                     {
                         let space = line.find(' ').unwrap();
                         normalized.push_str(&line[..space]);
@@ -532,7 +556,7 @@ fn unindent(diag: String) -> String {
     normalized
 }
 
-fn indented_line_kind(line: &str) -> IndentedLineKind {
+fn indented_line_kind(line: &str, normalization: Normalization) -> IndentedLineKind {
     if let Some(heading_len) = if line.starts_with("error") {
         Some("error".len())
     } else if line.starts_with("warning") {
@@ -545,7 +569,10 @@ fn indented_line_kind(line: &str) -> IndentedLineKind {
         }
     }
 
-    if line.starts_with("note:") || line == "..." {
+    if line.starts_with("note:")
+        || line == "..."
+        || normalization >= UnindentAfterHelp && line.starts_with("help:")
+    {
         return IndentedLineKind::Note;
     }
 
