@@ -1,5 +1,5 @@
 use std::env;
-use std::process::Command;
+use std::ffi::OsString;
 
 const RUSTFLAGS: &str = "RUSTFLAGS";
 const IGNORED_LINTS: &[&str] = &["dead_code"];
@@ -15,16 +15,13 @@ pub fn make_vec() -> Vec<&'static str> {
     rustflags
 }
 
-pub fn set_env(cmd: &mut Command) {
-    let mut rustflags = match env::var_os(RUSTFLAGS) {
-        Some(rustflags) => rustflags,
-        None => return,
-    };
+pub fn envs() -> impl IntoIterator<Item = (&'static str, OsString)> {
+    let mut rustflags = env::var_os(RUSTFLAGS)?;
 
     for flag in make_vec() {
         rustflags.push(" ");
         rustflags.push(flag);
     }
 
-    cmd.env(RUSTFLAGS, rustflags);
+    Some((RUSTFLAGS, rustflags))
 }
